@@ -16,6 +16,7 @@ from strawberry import (
     field,
     input,
     interface,
+    lazy,
     mutation,
     scalar,
     schema_directive,
@@ -55,6 +56,7 @@ __all__ = [
     "ID",
     "UNSET",
     "LazyType",
+    "lazy",
     "Private",
     "Schema",
     "argument",
