@@ -21,8 +21,9 @@ from django.core.exceptions import (
     ValidationError,
 )
 import strawberry
+from strawberry import UNSET
 from strawberry.annotation import StrawberryAnnotation
-from strawberry.arguments import UNSET, StrawberryArgument
+from strawberry.arguments import StrawberryArgument
 from strawberry.permission import BasePermission
 from strawberry.type import StrawberryType
 from strawberry.types.fields.resolver import StrawberryResolver
@@ -203,7 +204,11 @@ class DjangoInputMutationField(DjangoMutationField, relay.InputMutationField):
         input_obj = kwargs.pop("input", None)
 
         # FIXME: Any other exception types that we should capture here?
-        resolver = aio.resolver(self.resolver, on_error=_map_exception, info=info)
+        resolver = aio.resolver(
+            self.resolver,
+            on_error=_map_exception if self._handle_errors else None,
+            info=info,
+        )
         return resolver(source, info, input_obj, args, kwargs)
 
     def resolver(
@@ -291,7 +296,7 @@ class DjangoDeleteMutationField(DjangoInputMutationField):
         assert data is not None
 
         vdata = vars(data)
-        pk = vdata.pop("id")
+        pk = vdata.pop("id", UNSET)
         if pk is UNSET:
             pk = vdata.pop("pk")
 
@@ -307,7 +312,6 @@ class DjangoDeleteMutationField(DjangoInputMutationField):
 @overload
 def mutation(
     *,
-    input_type: Optional[type] = None,
     resolver: Callable[[], _T],
     name: Optional[str] = None,
     field_name: Optional[str] = None,
@@ -328,7 +332,6 @@ def mutation(
 @overload
 def mutation(
     *,
-    input_type: Optional[type] = None,
     name: Optional[str] = None,
     field_name: Optional[str] = None,
     filters: Any = UNSET,
@@ -349,7 +352,6 @@ def mutation(
 def mutation(
     resolver: Union[StrawberryResolver, Callable, staticmethod, classmethod],
     *,
-    input_type: Optional[type] = None,
     name: Optional[str] = None,
     field_name: Optional[str] = None,
     filters: Any = UNSET,
@@ -368,7 +370,6 @@ def mutation(
 def mutation(
     resolver=None,
     *,
-    input_type: Optional[type] = None,
     name: Optional[str] = None,
     field_name: Optional[str] = None,
     filters: Any = UNSET,
@@ -397,7 +398,6 @@ def mutation(
 
     """
     f = DjangoMutationField(
-        input_type=input_type,
         python_name=None,
         django_name=field_name,
         graphql_name=name,
@@ -546,6 +546,7 @@ def create(
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
     directives: Optional[Sequence[object]] = (),
+    handle_django_errors: bool = True,
 ) -> Any:
     """Create mutation for django input fields.
 
@@ -576,6 +577,7 @@ def create(
         default_factory=default_factory,
         directives=directives,
         filters=filters,
+        handle_django_errors=handle_django_errors,
     )
 
 
@@ -593,6 +595,7 @@ def update(
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
     directives: Optional[Sequence[object]] = (),
+    handle_django_errors: bool = True,
 ) -> Any:
     """Update mutation for django input fields.
 
@@ -621,6 +624,7 @@ def update(
         default_factory=default_factory,
         directives=directives,
         filters=filters,
+        handle_django_errors=handle_django_errors,
     )
 
 
@@ -638,6 +642,7 @@ def delete(
     default: Any = UNSET,
     default_factory: Union[Callable, object] = UNSET,
     directives: Optional[Sequence[object]] = (),
+    handle_django_errors: bool = True,
 ) -> Any:
     return DjangoDeleteMutationField(
         input_type=input_type,
@@ -653,4 +658,5 @@ def delete(
         default_factory=default_factory,
         directives=directives,
         filters=filters,
+        handle_django_errors=handle_django_errors,
     )
