@@ -14,6 +14,7 @@ from typing import (
     cast,
 )
 
+from django.contrib.contenttypes.fields import GenericForeignKey, GenericRelation
 from django.db import models
 from django.db.models import Prefetch
 from django.db.models.constants import LOOKUP_SEP
@@ -190,7 +191,13 @@ def _get_model_hints(
                     if f_store is not None:
                         model_cache.setdefault(f_model, []).append((level, f_store))
                         store |= f_store.with_prefix(path, info=info)
-            elif isinstance(model_field, (models.ManyToManyField, ManyToManyRel, ManyToOneRel)):
+            elif isinstance(model_field, GenericForeignKey):
+                # There's not much we can do to optimize generic foreign keys regarding
+                # only/select_related because they can be anything. Just prefetch_related them
+                store.prefetch_related.append(model_fieldname)
+            elif isinstance(
+                model_field, (models.ManyToManyField, ManyToManyRel, ManyToOneRel, GenericRelation)
+            ):
                 f_types = list(get_possible_type_definitions(field.type))
                 if len(f_types) > 1:
                     # This might be a generic foreign key. In this case, just prefetch it
@@ -208,6 +215,7 @@ def _get_model_hints(
                         model_cache=model_cache,
                         level=level + 1,
                     )
+
                     if f_store is not None:
                         if (
                             (config is None or config.enable_only)
@@ -216,7 +224,26 @@ def _get_model_hints(
                         ):
                             # If adding a reverse relation, make sure to select its pointer to us,
                             # or else this might causa a refetch from the database
-                            f_store.only.append(remote_field.attname or remote_field.name)
+                            if isinstance(model_field, GenericRelation):
+                                f_store.only.append(model_field.object_id_field_name)
+                                f_store.only.append(model_field.content_type_field_name)
+                            else:
+                                f_store.only.append(remote_field.attname or remote_field.name)
+
+                        path_lookup = f"{path}{LOOKUP_SEP}"
+                        if store.only and f_store.only:
+                            extra_only = [o for o in store.only or [] if o.startswith(path_lookup)]
+                            store.only = [o for o in store.only if o not in extra_only]
+                            f_store.only.extend(o[len(path_lookup) :] for o in extra_only)
+
+                        if store.select_related and f_store.select_related:
+                            extra_sr = [
+                                o for o in store.select_related or [] if o.startswith(path_lookup)
+                            ]
+                            store.select_related = [
+                                o for o in store.select_related if o not in extra_sr
+                            ]
+                            f_store.select_related.extend(o[len(path_lookup) :] for o in extra_sr)
 
                         model_cache.setdefault(remote_model, []).append((level, f_store))
 
@@ -432,7 +459,6 @@ class OptimizerStore:
             if isinstance(p, Callable):
                 assert_type(p, PrefetchCallable)
                 p = p(info)
-                p.add_prefix(prefix)
 
             if isinstance(p, str):
                 prefetch_related.append(f"{prefix}{LOOKUP_SEP}{p}")
@@ -463,6 +489,7 @@ class OptimizerStore:
                 p: p for p in self.prefetch_related if isinstance(p, str)
             }
 
+            abort_only = set()
             for p in self.prefetch_related:
                 # Already added above
                 if isinstance(p, str):
@@ -478,6 +505,7 @@ class OptimizerStore:
                 # In this case, just replace it.
                 if not existing or isinstance(existing, str):
                     to_prefetch[path] = p
+                    abort_only.add(path)
                     continue
 
                 p1 = PrefetchInspector(existing)
@@ -492,6 +520,10 @@ class OptimizerStore:
 
                 to_prefetch[path] = ret.prefetch
 
+            # Abort only optimization if one prefetch related was made for everything
+            for ao in abort_only:
+                to_prefetch[ao].queryset.query.deferred_loading = ([], True)  # type:ignore
+
             qs = qs.prefetch_related(*to_prefetch.values())
 
         if config.enable_select_related and self.select_related:
