@@ -29,7 +29,7 @@ from strawberry.private import Private
 from strawberry.schema_directive import Location
 from strawberry.types.info import Info
 from strawberry.utils.await_maybe import AwaitableOrValue
-from typing_extensions import Self, final
+from typing_extensions import Self, assert_never, final
 
 from .directives import SchemaDirectiveHelper, SchemaDirectiveWithResolver
 from .relay import Connection, GlobalID
@@ -166,7 +166,7 @@ def get_with_perms(
     info: Info,
     *,
     required: Literal[True],
-    model: Type[_M] = ...,
+    model: Type[_M],
 ) -> _M:
     ...
 
@@ -177,11 +177,31 @@ def get_with_perms(
     info: Info,
     *,
     required: bool = ...,
-    model: Type[_M] = ...,
+    model: Type[_M],
 ) -> Optional[_M]:
     ...
 
 
+@overload
+def get_with_perms(
+    pk: GlobalID,
+    info: Info,
+    *,
+    required: Literal[True],
+) -> Any:
+    ...
+
+
+@overload
+def get_with_perms(
+    pk: GlobalID,
+    info: Info,
+    *,
+    required: bool = ...,
+) -> Optional[Any]:
+    ...
+
+
 def get_with_perms(pk, info, *, required=False, model=None):
     if isinstance(pk, GlobalID):
         instance = pk.resolve_node(info, required=required, ensure_type=model)
@@ -241,6 +261,7 @@ class AuthDirective(SchemaDirectiveWithResolver):
                     resolver,
                     root,
                     info,
+                    **kwargs,
                 ),
                 info=info,
             )
@@ -251,6 +272,7 @@ class AuthDirective(SchemaDirectiveWithResolver):
             root,
             info,
             cast(UserType, user),
+            **kwargs,
         )
 
     def resolve_for_user(
@@ -260,6 +282,7 @@ class AuthDirective(SchemaDirectiveWithResolver):
         root: Any,
         info: GraphQLResolveInfo,
         user: UserType,
+        **kwargs,
     ):
         raise NotImplementedError
 
@@ -353,16 +376,17 @@ class ConditionDirective(AuthDirective):
         root: Any,
         info: GraphQLResolveInfo,
         user: UserType,
+        **kwargs,
     ):
         return self.resolve_retval(
             helper,
             root,
             info,
             resolver,
-            self.check_condition(root, info, user),
+            self.check_condition(root, info, user, **kwargs),
         )
 
-    def check_condition(self, root: Any, info: GraphQLResolveInfo, user: UserType):
+    def check_condition(self, root: Any, info: GraphQLResolveInfo, user: UserType, **kwargs):
         raise NotImplementedError
 
 
@@ -376,7 +400,7 @@ class IsAuthenticated(ConditionDirective):
 
     message: Private[str] = dataclasses.field(default="User is not authenticated.")
 
-    def check_condition(self, root: Any, info: GraphQLResolveInfo, user: UserType):
+    def check_condition(self, root: Any, info: GraphQLResolveInfo, user: UserType, **kwargs):
         return user.is_authenticated and user.is_active
 
 
@@ -390,7 +414,7 @@ class IsStaff(ConditionDirective):
 
     message: Private[str] = dataclasses.field(default="User is not a staff member.")
 
-    def check_condition(self, root: Any, info: GraphQLResolveInfo, user: UserType):
+    def check_condition(self, root: Any, info: GraphQLResolveInfo, user: UserType, **kwargs):
         return user.is_authenticated and user.is_staff
 
 
@@ -404,7 +428,7 @@ class IsSuperuser(ConditionDirective):
 
     message: Private[str] = dataclasses.field(default="User is not a superuser.")
 
-    def check_condition(self, root: Any, info: GraphQLResolveInfo, user: UserType):
+    def check_condition(self, root: Any, info: GraphQLResolveInfo, user: UserType, **kwargs):
         return user.is_authenticated and user.is_superuser
 
 
@@ -566,6 +590,7 @@ class HasPermDirective(AuthDirective):
         root: Any,
         info: GraphQLResolveInfo,
         user: UserType,
+        **kwargs,
     ):
         if self.with_superuser and user.is_active and user.is_superuser:
             return self.resolve_retval(helper, root, info, resolver, True)
@@ -600,7 +625,7 @@ class HasPermDirective(AuthDirective):
                 )
             return self._resolve_obj_perms(helper, root, info, user, ret)
         else:
-            raise AssertionError(f"Unknown target {self.target!r}")
+            assert_never(self.target)  # noqa:R503
 
     @resolvers.async_safe
     def _has_perm_safe(
