@@ -8,6 +8,7 @@ import inspect
 import math
 import sys
 from typing import (
+    TYPE_CHECKING,
     Any,
     Awaitable,
     Callable,
@@ -317,7 +318,7 @@ DEFAULT_SCALAR_REGISTRY[GlobalID] = ScalarDefinition(
     # specs expect this type to be "ID".
     name="GlobalID",
     description=GraphQLID.description,
-    parse_literal=lambda v: GlobalID.from_id(GraphQLID.parse_literal(v)),
+    parse_literal=lambda v, vars=None: GlobalID.from_id(GraphQLID.parse_literal(v, vars)),
     parse_value=GlobalID.from_id,
     serialize=str,
     specified_by_url="https://relay.dev/graphql/objectidentification.htm",
@@ -350,6 +351,11 @@ class Node(abc.ABC):
 
     """
 
+    # We can't do CONNECTION_CLASS = Connection because it is not defined yet.
+    # We will define it below though as the default one.
+    if TYPE_CHECKING:
+        CONNECTION_CLASS: ClassVar[Type["Connection"]]
+
     @strawberry.field(description="The Globally Unique ID of this object")
     @classmethod
     def id(cls, root: "Node", info: Info) -> GlobalID:  # noqa:A003
@@ -361,7 +367,10 @@ class Node(abc.ABC):
             resolve_id = cls.resolve_id
 
         node_id = resolve_id(root, info=info)
-        type_name = info.path.typename
+        resolve_typename = (
+            root.__class__.resolve_typename if isinstance(root, Node) else cls.resolve_typename
+        )
+        type_name = resolve_typename(root, info)
         assert type_name
 
         if isinstance(node_id, str):
@@ -405,6 +414,10 @@ class Node(abc.ABC):
         id_attr = getattr(cls, "id_attr", "id")
         return getattr(root, id_attr)
 
+    @classmethod
+    def resolve_typename(cls: Type[NodeType], root: NodeType, info: Info):
+        return info.path.typename
+
     @classmethod
     def resolve_connection(
         cls: Type[NodeType],
@@ -465,7 +478,7 @@ class Node(abc.ABC):
         # FIXME: Remove cast once pyright resolves the negative TypeGuard form
         nodes = cast(Iterable[NodeType], nodes)
 
-        return Connection.from_nodes(
+        return cls.CONNECTION_CLASS.from_nodes(
             nodes,
             total_count=total_count,
             before=before,
@@ -602,6 +615,10 @@ class Edge(Generic[NodeType]):
         description="The item at the end of the edge",
     )
 
+    @classmethod
+    def from_node(cls, node: NodeType, *, cursor: Any = None):
+        return cls(cursor=to_base64(connection_typename, cursor), node=node)
+
 
 @strawberry.type(description="A connection to a list of items.")
 class Connection(Generic[NodeType]):
@@ -617,6 +634,8 @@ class Connection(Generic[NodeType]):
 
     """
 
+    EDGE_CLASS: ClassVar[Type["Edge"]] = Edge
+
     page_info: PageInfo = strawberry.field(
         description="Pagination data for this connection",
     )
@@ -728,7 +747,7 @@ class Connection(Generic[NodeType]):
 
         # Overfetch by 1 to check if we have a next result
         edges = [
-            Edge(cursor=to_base64(connection_typename, start + i), node=v)
+            cls.EDGE_CLASS.from_node(v, cursor=start + i)
             for i, v in enumerate(cast(Sequence, nodes)[start : end + 1])  # noqa:E203
         ]
 
@@ -753,6 +772,9 @@ class Connection(Generic[NodeType]):
         )
 
 
+Node.CONNECTION_CLASS = Connection
+
+
 class RelayField(StrawberryField):
     """Base relay field, containing utilities for both Node and Connection fields."""
 
@@ -925,8 +947,9 @@ class ConnectionField(RelayField):
                 "like `Iterable[<NodeType>]`, `List[<NodeType>]`, etc"
             )
 
+        ntype = get_args(resolved)[0]
         type_override = StrawberryAnnotation(
-            Connection[get_args(resolved)[0]],  # type:ignore
+            ntype.CONNECTION_CLASS[ntype],
             namespace=namespace,
         ).resolve()
 
